@@ -2,14 +2,14 @@ package IO::Compress::Adapter::Lzma ;
 
 use strict;
 use warnings;
-# use bytes;
+use bytes;
 
-use IO::Compress::Base::Common  2.070 qw(:Status);
+use IO::Compress::Base::Common  2.072 qw(:Status);
 
-use Compress::Raw::Lzma  2.070 qw(LZMA_OK LZMA_STREAM_END) ;
+use Compress::Raw::Lzma  2.072 qw(LZMA_OK LZMA_STREAM_END) ;
 
-use vars qw($VERSION);
-$VERSION = '2.070';
+our ($VERSION);
+$VERSION = '2.072';
 
 sub mkCompObject
 {
