@@ -2,19 +2,19 @@ package IO::Compress::Lzma ;
 
 use strict ;
 use warnings;
-# use bytes;
+use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.070 ;
+use IO::Compress::Base 2.072 ;
 
-use IO::Compress::Base::Common  2.070 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Lzma 2.070 ;
+use IO::Compress::Base::Common  2.072 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Lzma 2.072 ;
 
 
 
-use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS $LzmaError);
+our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzmaError);
 
-$VERSION = '2.070';
+$VERSION = '2.072';
 $LzmaError = '';
 
 @ISA    = qw(Exporter IO::Compress::Base);
@@ -765,7 +765,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2016 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2017 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
