@@ -2,17 +2,17 @@ package IO::Uncompress::UnLzma ;
 
 use strict ;
 use warnings;
-# use bytes;
+use bytes;
 
-use IO::Compress::Base::Common 2.070 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common 2.072 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base 2.070 ;
-use IO::Uncompress::Adapter::UnLzma 2.070 ;
+use IO::Uncompress::Base 2.072 ;
+use IO::Uncompress::Adapter::UnLzma 2.072 ;
 
 require Exporter ;
-use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS $UnLzmaError);
+our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzmaError);
 
-$VERSION = '2.070';
+$VERSION = '2.072';
 $UnLzmaError = '';
 
 @ISA    = qw( Exporter IO::Uncompress::Base );
@@ -967,7 +967,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2016 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2017 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
